WindowBorder

Enum WindowBorder 

#[non_exhaustive]
pub enum WindowBorder { None, Single, Double, Rounded, Solid, Shadow, Uniform(WindowBorderChar), CornersEdges(WindowBorderChar, WindowBorderChar), CornersHorizontalVertical(WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar), Anal(WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar), }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

No border.



Single

A single line box.



Double

A double line box.



Rounded

Like Single, but with rounded corners (, etc).



Solid

Adds a single whitespace cell of padding.



Shadow

A drop shadow effect by blending with the background.



Uniform(WindowBorderChar)

A single character used for the whole border:

aaaaa a a a a aaaaa



CornersEdges(WindowBorderChar, WindowBorderChar)

A tuple (a, b) where a is used for the border’s corners and b for its edges:

abbba b b b b abbba



CornersHorizontalVertical(WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar)

A tuple (a, b, c, d) where a and c are used for the border’s corners, b for its horizontal edges and d for the vertical ones:

abbbc d d d d cbbba



Anal(WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar, WindowBorderChar)

Use this if you’re a control freak and want to specify every single corner and edge character individually. The tuple (a, b, c, d, e, f, g, h) specifies every corner and edge character clockwise:

abbbc h d h d gfffe