KeymapInfos

Struct KeymapInfos 

#[non_exhaustive]
pub struct KeymapInfos { pub buffer: Option<Buffer>, pub callback: Option<Function<(), ()>>, pub expr: bool, pub lhs: String, pub lnum: Option<u32>, pub mode: Mode, pub noremap: bool, pub nowait: bool, pub rhs: Option<String>, pub script: bool, pub sid: i32, pub silent: bool, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
buffer: Option<Buffer>

When the KeymapInfos are returned from Buffer::get_keymap(), this will contain the Buffer it was called on. None when returned from get_keymap().

callback: Option<Function<(), ()>>

Optional callback triggered by the keymap.

expr: bool

Whether the keymap argument is an expression.

lhs: String

The left-hand side of the mapping.

lnum: Option<u32>

The number where a script-local mapping is defined, if known.

mode: Mode

The modes for which the keymap is enabled.

noremap: bool

Whether the right-hand side of the mapping is not remappable.

nowait: bool

For buffer-local mappings, whether Neovim should wait for more characters to be typed if there’s a global mapping that could also match. See :h map-nowait for more details.

rhs: Option<String>

The right-hand side of the mapping.

script: bool

Whether the mapping was defined with <script>.

sid: i32

The script-local ID, used for <sid> mappings.

silent: bool

Whether the keymap is silent.