Struct ParsedVimLExpression
#[non_exhaustive]pub struct ParsedVimLExpression {
pub ast: Option<VimLExpressionAst>,
pub error: Option<ParseExpressionError>,
pub highlight: Vec<(usize, usize, usize, String)>,
pub len: usize,
}Expand description
Informations about a parsed VimL expression returned by
parse_expression.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ast: Option<VimLExpressionAst>The syntax tree of the parsed expression.
error: Option<ParseExpressionError>Only present if there was an error parsing the expression.
highlight: Vec<(usize, usize, usize, String)>Only present if include_highlight was set to true when calling
parse_expression. The first three items of
the tuples represent the line, starting column and ending column
(exclusive) of each highlight, while the last item is the highlight
group name.
len: usizeNumber of bytes successfully parsed.